from .stablecoin import JettonMasterStablecoin, JettonWalletStablecoin
from .standard import JettonMasterStandard, JettonWalletStandard

__all__ = [
    "JettonMasterStablecoin",
    "JettonWalletStablecoin",

    "JettonMasterStandard",
    "JettonWalletStandard",
]
